CompareRecipe: Generating comparison values — Recipe 0.8.0 documentation

# CompareRecipe: Generating comparison values

The CompareRecipe extension lets you generate different Recipes againt the same table to generate comparison values.

class `recipe.` `CompareRecipe`(*args, **kwargs)

  Add compare recipes, used for presenting comparative context vis-a-vis a base recipe.

  Supply a second recipe with the same ``from`. Metrics from the second recipe will be hoisted to the base recipe and suffixed with a string (the default is “_compare” Dimensions will be used to match the base recipe to the compare recipe. Ordering from the base recipe is maintained.

  `compare`(compare_recipe, suffix='_compare')

    Adds a comparison recipe to a base recipe.